@@ -1,5 +1,5 @@
 from stockquant.source.baostockdata import BaoStockData
-from stockquant.source.sinadata import SinaData
+from stockquant.source.money import MoneyData
 from stockquant.source.tusharedata import TuShareData
 from stockquant.utils.tools import get_localtime
 from stockquant.utils.logger import logger
@@ -18,8 +18,7 @@ class Market:
         :param symbol: 例如："sh601003"，或者"sz002307"，前者是沪市，后者是深市
         :return:返回一个字典
         """
-        logger.debug("It is recommended to increase the time interval when calling real-time data ！")
-        return SinaData.get_realtime_data(symbol)
+        return MoneyData.get_realtime_data(symbol)
 
     @staticmethod
     def shenzhen_component_index():
@@ -27,7 +26,7 @@ class Market:
         获取深圳成指
         :return:返回一个字典
         """
-        return SinaData.shenzhen_component_index()
+        return MoneyData.shenzhen_component_index()
 
     @staticmethod
     def shanghai_component_index():
@@ -35,7 +34,7 @@ class Market:
         获取上证综指
         :return:
         """
-        return SinaData.shanghai_component_index()
+        return MoneyData.shanghai_component_index()
 
     """
     BaoStockData
